@@ -12,15 +12,17 @@ For usage information, run `sntools -h` or `python sntools/genevts.py -h`.
 For more extensive documentation, to report issues or to contribute code,
 see https://github.com/JostMigenda/sntools.
 """
+from __future__ import print_function
 
-__version__ = '0.7.2.post1'
+__version__ = '0.7.4'
 
 
 def setup():
     """
     Downloads sample flux file from GitHub if necessary and performs integration test.
     """
-    print(u"\u2705 sntools was imported from " + __path__[0])
+    tryprint(u"\u2705", "[SUCCESS]")
+    print("sntools was imported from " + __path__[0])
     import hashlib
     import os
     import sys
@@ -30,9 +32,11 @@ def setup():
     flux_file = flux_dir + 'intp2001.data'
     flux_url = 'https://raw.githubusercontent.com/JostMigenda/sntools/master/fluxes/intp2001.data'
     if os.path.exists(flux_file):
-        print(u"\u2705 Using sample flux file at " + flux_file)
+        tryprint(u"\u2705", "[SUCCESS]")
+        print("Using sample flux file at " + flux_file)
     else:
-        print(u"\U0001f6e0 Downloading sample flux file from " + flux_url)
+        tryprint(u"\U0001f6e0")
+        print("Downloading sample flux file from " + flux_url)
         if not os.path.isdir(flux_dir):
             os.mkdir(flux_dir)
         try:
@@ -41,23 +45,38 @@ def setup():
             from urllib import urlretrieve  # Python 2.7
         try:
             urlretrieve(flux_url, filename=flux_file)
-            print(u"\u2705 Saved sample flux file to " + flux_file)
+            tryprint(u"\u2705", "[SUCCESS]")
+            print("Saved sample flux file to " + flux_file)
         except IOError:
-            print(u"\u274c Error: Cannot download sample flux file.")
+            tryprint(u"\u274c", "[ERROR]")
+            print("Cannot download sample flux file.")
             sys.exit(-1)
 
-    print(u"\U0001f6e0 Testing event generation ...")
+    tryprint(u"\U0001f6e0")
+    print("Testing event generation ...")
     sys.argv += [flux_file, '--format', 'nakazato', '--detector', 'WATCHMAN-LS', '--distance', '2', '--ordering', 'normal', '--starttime', '100', '--endtime', '300', '-o', 'outfile.kin', '--randomseed', '314']
     genevts.main()
 
-    print(u"\U0001f6e0 Checking output file ...")
+    tryprint(u"\U0001f6e0")
+    print("Checking output file ...")
     with open('outfile.kin', 'rb') as f:
         output_sha = hashlib.sha256(f.read()).hexdigest()
-    
-    test_sha = "6173ea086aab0590212d0207612d57a46184f7569d0205d322fe3b5689f5f700"
+
+    test_sha = "8bdd9308e866076aeae2f01272a9b3025f438e2d727698da0714cf931ff556d6"
     if output_sha == test_sha:
-        print(u"\u2705 Everything seems to work fine. Enjoy using sntools!")
+        tryprint(u"\u2705", "[SUCCESS]")
+        print("Everything seems to work fine. Enjoy using sntools!")
     else:
-        print(u"\u274c Error: Test did not generate the expected events.\n"
-              u"\u274c Please ensure you have installed the most recent version of sntools and all dependencies.\n"
-              u"\u274c If this persists, please go to https://github.com/JostMigenda/sntools and open a new issue.")
+        tryprint(u"\u274c", "[ERROR]")
+        print("Test did not generate the expected events.")
+        tryprint(u"\u274c", "[ERROR]")
+        print("Please ensure you have installed the most recent version of sntools and all dependencies.")
+        tryprint(u"\u274c", "[ERROR]")
+        print("If this persists, please go to https://github.com/JostMigenda/sntools and open a new issue.")
+
+
+def tryprint(default, alternative=''):
+    try:
+        print(default, end=' ')
+    except UnicodeEncodeError:
+        print(alternative, end=' ')
